@@ -8,6 +8,7 @@ from affinegap import normalizedAffineGapDistance as compareString
 import functools
 
 class ParseratorType(StringType) :
+    type = None
 
     def __len__(self) :
         return self.expanded_size
@@ -52,7 +53,7 @@ class ParseratorType(StringType) :
                 import csv
                 with open(self.log_file, 'a') as f :
                     writer = csv.writer(f)
-                    writer.writerow([e.original_string])
+                    writer.writerow([e.original_string.encode('utf8')])
             distances[i:3] = [1, 0]
             distances[-1] = compareString(field_1, field_2)
             return distances
